@@ -1,4 +1,4 @@
 package Not::Corinna::Role::Created {
     use MooseX::Extended::Role types => ['PositiveInt'];
-    field created => ( isa => PositiveInt, default => sub {time} );
+    field created => ( isa => PositiveInt, lazy => 0, default => sub {time} );
 }
